@@ -1,6 +1,6 @@
 package App::FileSummoner::Register::Rules;
 BEGIN {
-  $App::FileSummoner::Register::Rules::VERSION = '0.003';
+  $App::FileSummoner::Register::Rules::VERSION = '0.004';
 }
 
 use strict;
@@ -10,25 +10,24 @@ use File::Basename qw(basename dirname);
 
 use Exporter 'import';
 our @EXPORT = qw(
-    HasExt
-    InsideDirectory
-    BelowDirectory
+  HasExt
+  IsInsideDirectory
+  PathContains
 );
 
-sub InsideDirectory {
+sub IsInsideDirectory {
     my ($dir) = @_;
     return sub {
         my ($fileName) = @_;
-        return $dir eq basename(dirname($fileName));
+        return $dir eq basename( dirname($fileName) );
     };
 }
 
-sub BelowDirectory {
-    my ($dir) = @_;
+sub PathContains {
+    my ($pathPart) = @_;
     return sub {
         my ($fileName) = @_;
-        my @dirs = File::Spec->splitdir($fileName);
-        return $dir ~~ @dirs;
+        return $fileName =~ /\Q$pathPart\E/;
     };
 }
 
